#!/usr/bin/env python
"H2 correlation energy via MP2"

from PyQuante.Ints import getbasis,getints
from PyQuante.hartree_fock import rhf
from PyQuante.Molecule import Molecule
from PyQuante.MP import MP2

# GAMESS-UK SCF ENERGY -1.0882670560
# GAMESS-UK MP2 ENERGY -1.11591790

energy = -1.1153708         #Original value
energy = -1.11591861694     #After increasing accuracy of HF convergence
name = "H2_MP2"

def main():
    atoms = Molecule('h2',[(1,(1.,0,0)),(1,(-1.,0,0))])
    bfs = getbasis(atoms)
    nel = atoms.get_nel()
    nbf = len(bfs)
    nocc = nel/2
    S,h,Ints = getints(bfs,atoms)
    en,orbe,orbs = rhf(atoms,integrals=(S,h,Ints),)
    print "SCF completed, E = ",en 

    emp2 = MP2(Ints,orbs,orbe,nocc,nbf-nocc)  
    print "MP2 correction = ",emp2 
    print "Final energy = ",en+emp2 
    return en+emp2

if __name__ == '__main__': main() 


    

    
